@@ -43,7 +43,7 @@ class pkgAcqMetaClearSig;
 class pkgAcqIndexMergeDiffs;
 class metaIndex;
 
-class pkgAcquire::Item : public WeakPointable				/*{{{*/
+class APT_PUBLIC pkgAcquire::Item : public WeakPointable				/*{{{*/
 /** \brief Represents the process by which a pkgAcquire object should
  *  retrieve a file or a collection of files.
  *
@@ -152,6 +152,9 @@ class pkgAcquire::Item : public WeakPointable				/*{{{*/
     */
    std::string DestFile;
 
+   /** \brief Number of retries */
+   unsigned int Retries;
+
    /** \brief Invoked by the acquire worker when the object couldn't
     *  be fetched.
     *
@@ -231,8 +234,6 @@ class pkgAcquire::Item : public WeakPointable				/*{{{*/
     *  no trailing newline.
     */
    virtual std::string Custom600Headers() const;
-   // Retries should really be a member of the Item, but can't be for ABI reasons
-   APT_HIDDEN unsigned int &ModifyRetries();
    // this is more a hack than a proper external interface, hence hidden
    APT_HIDDEN std::unordered_map<std::string, std::string> &ModifyCustomFields();
    // this isn't the super nicest interface either…
@@ -939,7 +940,7 @@ class APT_HIDDEN pkgAcqIndexDiffs : public pkgAcqBaseIndex
  *  If the package file already exists in the cache, nothing will be
  *  done.
  */
-class pkgAcqArchive : public pkgAcquire::Item
+class APT_PUBLIC pkgAcqArchive : public pkgAcquire::Item
 {
    void * const d;
 
@@ -1017,7 +1018,7 @@ class pkgAcqArchive : public pkgAcquire::Item
  *  Downloads the changelog to a temporary file it will also remove again
  *  while it is deconstructed or downloads it to a named location.
  */
-class pkgAcqChangelog : public pkgAcquire::Item
+class APT_PUBLIC pkgAcqChangelog : public pkgAcquire::Item
 {
    class Private;
    Private * const d;
@@ -1133,7 +1134,7 @@ private:
  *  normally is a NOP, such as "file".  If the download fails, the
  *  partial file is renamed to get a ".FAILED" extension.
  */
-class pkgAcqFile : public pkgAcquire::Item
+class APT_PUBLIC pkgAcqFile : public pkgAcquire::Item
 {
    void * const d;
 
@@ -1146,7 +1147,6 @@ class pkgAcqFile : public pkgAcquire::Item
    virtual bool HashesRequired() const APT_OVERRIDE;
 
    // Specialized action members
-   virtual void Failed(std::string const &Message,pkgAcquire::MethodConfig const * const Cnf) APT_OVERRIDE;
    virtual void Done(std::string const &Message, HashStringList const &CalcHashes,
 		     pkgAcquire::MethodConfig const * const Cnf) APT_OVERRIDE;
    virtual std::string DescURI() const APT_OVERRIDE {return Desc.URI;};
