@@ -536,18 +536,12 @@ void pkgAcquire::SetFds(int &Fd,fd_set *RSet,fd_set *WSet)
    }
 }
 									/*}}}*/
-// Acquire::RunFds - compatibility remove on next abi/api break		/*{{{*/
-void pkgAcquire::RunFds(fd_set *RSet,fd_set *WSet)
-{
-   RunFdsSane(RSet, WSet);
-}
-									/*}}}*/
-// Acquire::RunFdsSane - Deal with active FDs				/*{{{*/
+// Acquire::RunFds - Deal with active FDs				/*{{{*/
 // ---------------------------------------------------------------------
 /* Dispatch active FDs over to the proper workers. It is very important
    that a worker never be erased while this is running! The queue class
    should never erase a worker except during shutdown processing. */
-bool pkgAcquire::RunFdsSane(fd_set *RSet,fd_set *WSet)
+bool pkgAcquire::RunFds(fd_set *RSet,fd_set *WSet)
 {
    bool Res = true;
 
@@ -726,7 +720,7 @@ pkgAcquire::RunResult pkgAcquire::Run(int PulseIntervall)
 	 break;
       }
 
-      if(RunFdsSane(&RFds,&WFds) == false)
+      if(RunFds(&RFds,&WFds) == false)
          break;
 
       // Timeout, notify the log class
