@@ -9,11 +9,11 @@
  * (at your option) any later version.
  */
 
-#if !defined(APT_STRINGVIEW_H) && defined(APT_PKG_EXPOSE_STRING_VIEW)
+#if !defined(APT_STRINGVIEW_H)
 #define APT_STRINGVIEW_H
-#include <string.h>
-#include <string>
 #include <apt-pkg/macros.h>
+#include <string>
+#include <string.h>
 
 namespace APT {
 
@@ -24,7 +24,7 @@ namespace APT {
  * used by APT. It is not meant to be used in programs, only inside the
  * library for performance critical paths.
  */
-class APT_HIDDEN StringView {
+class StringView {
     const char *data_;
     size_t size_;
 
@@ -123,10 +123,15 @@ static inline int StringViewCompareFast(StringView a, StringView b) {
     return memcmp(a.data(), b.data(), a.size());
 }
 
-
+static constexpr inline APT::StringView operator""_sv(const char *data, size_t size)
+{
+   return APT::StringView(data, size);
+}
 }
 
 inline bool operator ==(const char *other, APT::StringView that);
 inline bool operator ==(const char *other, APT::StringView that) { return that.operator==(other); }
+inline bool operator ==(std::string const &other, APT::StringView that);
+inline bool operator ==(std::string const &other, APT::StringView that) { return that.operator==(other); }
 
 #endif
